@@ -477,13 +477,13 @@ class MetricsBase(Compute):
             )
 
         args = self.args
-        start_date = self.args["start_date"]
-        end_date = self.args["end_date"]
+
+        start_date = source.get('start_date', self.args["start_date"])
+        end_date = source.get('end_date', self.args["end_date"])
 
         name = source["name"]
         dataset = source["dataset"]
         params = source.get("params", {})
-        setdate = source.get("date", False)
 
         cache = args.get("cache", False)
         cachename = f"{dataset}-{start_date}-{end_date}"
