@@ -12,11 +12,11 @@ dumped into the metadata.json at the end of the run.
 The metadata associated with a data object includes::
 
   1. Name of the frame (each data object has a unique name)
-  2. Category of the data object 
-  3. Type of frame (e.g., pandas, html, dict) 
-  4. History of access to the dataframe 
+  2. Category of the data object
+  3. Type of frame (e.g., pandas, html, dict)
+  4. History of access to the dataframe
   5. Parameters that can have arbitrary informations such as
-     column documentation, security, messages etc. 
+     column documentation, security, messages etc.
   6. Stages that each data object goes through
 
 
@@ -54,6 +54,7 @@ class EnrichStateBase(object):
         self.status = "started"
         self.summary = []  # notes that must be shared.
         self.performance_summary = []
+        self.dataset_accesses = []
         self.frames = {}
         self.transforms = {}
         self.transform_overrides = {}
@@ -156,3 +157,12 @@ class EnrichStateBase(object):
 
         """
         pass
+
+    def make_dataset_access_note(self, dataset, metadata, nature="read-write"):
+        self.dataset_accesses.append({
+            'timestamp': datetime.now(),
+            'name': dataset.name,
+            'nature': nature,
+            'description': dataset.description,
+            'metadata': metadata
+        })
