@@ -462,13 +462,6 @@ def prepare_dashboard(target, templatepath):
             {
                 "installed_apps": [
                     f"{appname}.apps.{appname}Config"
-                ],
-                "applications": [
-                    {
-                        "url": f"{appname}:index",
-                        "description": "Update me",
-                        "name": f"{appname.title()}"
-                    }
                 ]
             },
             indent=4,
@@ -506,8 +499,8 @@ def prepare_asset(what, target, templatepath):
     '''
 
     # Initialize the library...
-    basename = os.path.basename(target)
-    initfile = os.path.join(target, "src", basename, "__init__.py")
+    libname = os.path.basename(target)
+    initfile = os.path.join(target, "src", libname, "__init__.py")
     try:
         os.makedirs(os.path.dirname(initfile))
     except:
@@ -515,8 +508,23 @@ def prepare_asset(what, target, templatepath):
     with open(initfile, "w") as fd:
         fd.write(content)
 
+    s3root = prompt("s3root>")
+    servername = prompt("servername>")
+
+    asset_root = get_template_path("assets")
+    files = glob2.glob(asset_root + "/*py")
+    for f in files:
+        content = open(f).read()
+        content = content.replace("S3ROOT", s3root)
+        content = content.replace("SERVERNAME", servername)
+        basename = os.path.basename(f)
+        targetfile = os.path.join(target, "src", libname, basename)
+        with open(targetfile, "w") as fd:
+            fd.write(content)
+        print(basename, "=>", targetfile)
+
     # Bye bye
-    print("Bootstrapped asset library {} in {}".format(basename, target))
+    print("Bootstrapped asset library {}".format(target))
 
 
 def prepare_component(what, target, templatepath):
@@ -1056,6 +1064,8 @@ def bootstrap(component, path, templatepath):
         prepare_transform_script(path, templatepath, what="helloworld")
     elif component in ["transform-query"]:
         prepare_transform_script(path, templatepath, what="query")
+    elif component in ["transform-iris"]:
+        prepare_transform_script(path, templatepath, what="iris")
     # elif component == 'model':
     #    prepare_component('model', path, templatepath)
     # elif component == 'skin':
