@@ -87,6 +87,7 @@ class MockState(object):
         self.notes = []
         self.performance_notes = []
         self.expectations = []
+        self.dataset_accesses = []
         self.notifications = {"email": []}
         user = getpass.getuser()
         self.pid = os.getpid()
@@ -107,6 +108,18 @@ class MockState(object):
     def make_note(self, text):
         self.notes.append(text)
 
+    def make_dataset_access_note(self, dataset, metadata, nature='read-write'):
+        if dataset is None:
+            return
+
+        self.dataset_accesses.append({
+            'timestamp': datetime.now(),
+            'name': dataset.name,
+            'nature': nature,
+            'description': dataset.description,
+            'metadata': metadata
+        })
+
     def make_performance_note(
         self, name, description, condition, priority=1, message=""
     ):
@@ -626,6 +639,7 @@ class MockConfig(object):
                 "frames": self.state.state,
                 "expectations": self.state.expectations,
                 "accesses": self.accessed_files,
+                "dataset_accesses": self.state.dataset_accesses,
                 "versionmap": self.versionmap,
             },
             cls=CustomEncoder,
